==> qt-creator-opensource-src-4.8.1.zip: qt-creator-opensource-src-4.8.1/src/libs/clangsupport/pchmanagerclientinterface.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "pchmanagerclientinterface.h"
#include "messageenvelop.h"

#include <precompiledheadersupdatedmessage.h>

#include <QDebug>

namespace ClangBackEnd {

void PchManagerClientInterface::dispatch(const MessageEnvelop &messageEnvelop)
{
    switch (messageEnvelop.messageType()) {
        case MessageType::AliveMessage:
            alive();
            break;
        case MessageType::PrecompiledHeadersUpdatedMessage:
            precompiledHeadersUpdated(messageEnvelop.message<PrecompiledHeadersUpdatedMessage>());
            break;
        default:
            qWarning() << "Unknown IpcClientMessage";
    }
}

} // namespace ClangBackEnd

==> qt-creator-opensource-src-4.12.3.zip: qt-creator-opensource-src-4.12.3/src/libs/clangsupport/pchmanagerclientinterface.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "pchmanagerclientinterface.h"
#include "messageenvelop.h"

#include <precompiledheadersupdatedmessage.h>
#include <progressmessage.h>

#include <QDebug>

namespace ClangBackEnd {

void PchManagerClientInterface::dispatch(const MessageEnvelop &messageEnvelop)
{
    switch (messageEnvelop.messageType()) {
        case MessageType::AliveMessage:
            alive();
            break;
        case MessageType::PrecompiledHeadersUpdatedMessage:
            precompiledHeadersUpdated(messageEnvelop.message<PrecompiledHeadersUpdatedMessage>());
            break;
        case MessageType::ProgressMessage:
            progress(messageEnvelop.message<ProgressMessage>());
            break;
        default:
            qWarning() << "Unknown IpcClientMessage";
    }
}

} // namespace ClangBackEnd
